@@ -3,4 +3,4 @@
 
 
 def test():
-    print 'success'
\ No newline at end of file
+    print('success')
\ No newline at end of file
